@@ -1,4 +1,6 @@
-from .client import SliverClient, AsyncSliverClient, InteractiveSession, AsyncInteractiveSession
+from .client import SliverClient
+from .session import InteractiveSession
+from .beacon import InteractiveBeacon
 from .config import SliverClientConfig
 
 from .protobuf import common_pb2
